#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date : 05/04/2024

import vmp
import vmp_plugin as plugin

def module(par,var):
  m=plugin.module_import(par[0])
  if len(par) == 1:
    vmp.output(m.print_topic())
  else:
    try:
      topic=plugin.plugin_import_topic(par[0],par[1])
      vmp.output("{0}".format(topic.print_topic()))
    except Exception as e:
      vmp.error(str(e))

def vmp_main():
  vmp.input_f("module",module)
  vmp.exit_ok() 

    
  

